==> it-2.14.zip: it/public.lang.php <==
<?php
/**
 * @package Dotclear
 *
 * @copyright Olivier Meunier & Association Dotclear
 * @copyright GPL-2.0-only
 */#
#
#
#        DOT NOT MODIFY THIS FILE !




$GLOBALS['__l10n']['To content'] = 'Al contenuto';
$GLOBALS['__l10n']['To menu'] = 'Al menu';
$GLOBALS['__l10n']['To search'] = 'Alla ricerca';
$GLOBALS['__l10n']['By'] = 'Da';
$GLOBALS['__l10n']['by'] = 'da';
$GLOBALS['__l10n']['on'] = 'il';
$GLOBALS['__l10n']['On'] = 'Il';
$GLOBALS['__l10n']['Continue reading'] = 'Continua lettura';
$GLOBALS['__l10n']['no comments'] = 'nessuno commento';
$GLOBALS['__l10n']['one comment'] = 'un commento';
$GLOBALS['__l10n']['%d comments'] = '%d commenti';
$GLOBALS['__l10n']['no trackbacks'] = 'nessun trackback';
$GLOBALS['__l10n']['one trackback'] = 'un trackback';
$GLOBALS['__l10n']['%d trackbacks'] = '%d trackback';
$GLOBALS['__l10n']['no attachments'] = 'nessun allegato';
$GLOBALS['__l10n']['one attachment'] = 'un allegato';
$GLOBALS['__l10n']['%d attachments'] = '%d allegati';
$GLOBALS['__l10n']['previous entries'] = 'articoli precedenti';
$GLOBALS['__l10n']['page'] = 'pagina';
$GLOBALS['__l10n']['of'] = 'di';
$GLOBALS['__l10n']['next entries'] = 'articoli successivi';
$GLOBALS['__l10n']['Search'] = 'Cerca';
$GLOBALS['__l10n']['Your search for <em>%1$s</em> returned no result.'] = 'Non è stato trovato alcun risultato per la ricerca di <em>%1$s</em>.';
$GLOBALS['__l10n']['Your search for <em>%1$s</em> returned <strong>%2$s</strong> result.'] = 'È stato trovato <strong>%2$s</strong> risultato per la ricerca di <em>%1$s</em>.';
$GLOBALS['__l10n']['Your search for <em>%1$s</em> returned <strong>%2$s</strong> results.'] = 'Sono stati trovati <strong>%2$s</strong> risultati per la ricerca di <em>%1$s</em>.';
$GLOBALS['__l10n']['Home'] = 'Home';
$GLOBALS['__l10n']['All keywords'] = 'Tutte le parole chiave';
$GLOBALS['__l10n']['Best of me'] = 'Articoli migliori';
$GLOBALS['__l10n']['Languages'] = 'Lingue';
$GLOBALS['__l10n']['Categories'] = 'Categorie';
$GLOBALS['__l10n']['Subcategories'] = 'Sotto-categorie';
$GLOBALS['__l10n']['Archives'] = 'Archivi';
$GLOBALS['__l10n']['Links'] = 'Link';
$GLOBALS['__l10n']['Subscribe'] = 'Sottoscrivi';
$GLOBALS['__l10n']['Entries feed'] = 'Feed degli articoli';
$GLOBALS['__l10n']['Comments feed'] = 'Feed dei commenti';
$GLOBALS['__l10n']['This blog\'s comments Atom feed'] = 'Feed Atom dei commenti di questo blog';
$GLOBALS['__l10n']['This category\'s entries Atom feed'] = 'Feed Atom degli articoli di questa categoria';
$GLOBALS['__l10n']['This category\'s comments Atom feed'] = 'Feed Atom dei commenti di questa categoria';
$GLOBALS['__l10n']['This post\'s comments feed'] = 'Feed dei commenti di questo articolo';
$GLOBALS['__l10n']['This post\'s comments Atom feed'] = 'Feed Atom dei commenti di questo articolo';
$GLOBALS['__l10n']['Attachments'] = 'Allegati';
$GLOBALS['__l10n']['Permalink'] = 'Permalink';
$GLOBALS['__l10n']['Comments'] = 'Commenti';
$GLOBALS['__l10n']['Your comment'] = 'Il tuo commento';
$GLOBALS['__l10n']['Your comment has been published.'] = 'Il tuo commento è stato pubblicato.';
$GLOBALS['__l10n']['Your comment has been submitted and will be reviewed for publication.'] = 'Il tuo commento è stato inviato e sarà controllato prima di essere pubblicato.';
$GLOBALS['__l10n']['Add a comment'] = 'Scrivi un commento';
$GLOBALS['__l10n']['Name or nickname'] = 'Nome o nickname';
$GLOBALS['__l10n']['Email address'] = 'Indirizzo email';
$GLOBALS['__l10n']['Website'] = 'Sito web';
$GLOBALS['__l10n']['optional'] = 'facoltativo';
$GLOBALS['__l10n']['Comment'] = 'Commento';
$GLOBALS['__l10n']['Comments can be formatted using a simple wiki syntax.'] = '';
$GLOBALS['__l10n']['HTML code is displayed as text and web addresses are automatically converted.'] = 'Il codice HTML è mostrato come testo e gli indirizzi web sono automaticamente convertiti.';
$GLOBALS['__l10n']['Remember me on this blog'] = 'Ricordami su questo blog';
$GLOBALS['__l10n']['preview'] = 'anteprima';
$GLOBALS['__l10n']['send'] = 'invia';
$GLOBALS['__l10n']['They posted on the same topic'] = 'Hanno scritto sullo stesso argomento';
$GLOBALS['__l10n']['Trackback URL'] = 'URL trackback';
$GLOBALS['__l10n']['You must provide an author name'] = 'È necessario inserire il nome dell\'autore';
$GLOBALS['__l10n']['You must provide a comment'] = 'È necessario inserire un commento';
$GLOBALS['__l10n']['Email address is not valid'] = 'Indirizzo email non valido';
$GLOBALS['__l10n']['Document not found'] = 'Documento non trovato';
$GLOBALS['__l10n']['The document you are looking for does not exist.'] = 'Il documento richiesto non esiste.';
$GLOBALS['__l10n']['Powered by %s'] = 'Creato con %s';
$GLOBALS['__l10n']['Subscribe to'] = 'Iscriviti a';
$GLOBALS['__l10n']['What is an RSS feed?'] = 'Che cos\'è un feed RSS?';
$GLOBALS['__l10n']['RSS feed is a free blog summary. It provides content (either posts or comments) or summaries of content, together with links to the full versions, and other metadata. The last published items may then be read by your favorite RSS <a href="http://en.wikipedia.org/wiki/Aggregator">aggregator</a>.'] = 'Un feed RSS è il riassunto di un blog. Permette di leggere direttamente i contenuti (come gli articoli o i commenti) o loro riassunti, ed include inoltre un link alla relativa pagina del blog. Per mantenersi aggiornati sui nuovi articoli pubblicati, è possibile iscriversi attraverso un <a href="http://it.wikipedia.org/wiki/Aggregatore">aggregatore di feed</a>.';
$GLOBALS['__l10n']['Simply copy the following URL into your aggregator:'] = 'È sufficiente copiare il seguente URL all\'interno del proprio aggregatore:';
$GLOBALS['__l10n']['Password needed'] = 'Password richiesta';
$GLOBALS['__l10n']['You must give a password to access this area.'] = 'Per accedere in quest\'area del sito è necessario inserire la password.';
$GLOBALS['__l10n']['Password:'] = 'Password:';
$GLOBALS['__l10n']['You must provide a valid email address.'] = 'È necessario fornire un indirizzo email valido.';
$GLOBALS['__l10n']['Read'] = 'Leggi';
$GLOBALS['__l10n']['in'] = '';
$GLOBALS['__l10n']['In'] = '';
$GLOBALS['__l10n']['Page top'] = '';
$GLOBALS['__l10n']['toDay'] = '';
$GLOBALS['__l10n']['FromDay'] = '';
$GLOBALS['__l10n']['By category'] = '';
$GLOBALS['__l10n']['By date'] = '';
$GLOBALS['__l10n']['By tag'] = '';
$GLOBALS['__l10n']['Blog menu'] = 'Al menu';
$GLOBALS['__l10n']['Etra menu'] = 'Al menu';
$GLOBALS['__l10n']['Blog info'] = '';

==> it-2.17.zip: it/public.lang.php <==
<?php
/**
 * @package Dotclear
 *
 * @copyright Olivier Meunier & Association Dotclear
 * @copyright GPL-2.0-only
 */#
#
#
#        DOT NOT MODIFY THIS FILE !




$GLOBALS['__l10n']['%d attachments'] = '%d allegati';
$GLOBALS['__l10n']['%d comments'] = '%d commenti';
$GLOBALS['__l10n']['%d trackbacks'] = '%d trackback';
$GLOBALS['__l10n']['%s reactions'] = '';
$GLOBALS['__l10n']['Access to content'] = 'Al contenuto';
$GLOBALS['__l10n']['Add a comment'] = 'Scrivi un commento';
$GLOBALS['__l10n']['Add ping'] = '';
$GLOBALS['__l10n']['Additionnal style directives'] = '';
$GLOBALS['__l10n']['All keywords'] = 'Tutte le parole chiave';
$GLOBALS['__l10n']['Archives'] = 'Archivi';
$GLOBALS['__l10n']['Attachments'] = 'Allegati';
$GLOBALS['__l10n']['Best of me'] = 'Articoli migliori';
$GLOBALS['__l10n']['Blog info'] = '';
$GLOBALS['__l10n']['Blog menu'] = 'Al menu';
$GLOBALS['__l10n']['By'] = 'Da';
$GLOBALS['__l10n']['By category'] = '';
$GLOBALS['__l10n']['By date'] = '';
$GLOBALS['__l10n']['By tag'] = '';
$GLOBALS['__l10n']['Categories'] = 'Categorie';
$GLOBALS['__l10n']['Comment'] = 'Commento';
$GLOBALS['__l10n']['Comments'] = 'Commenti';
$GLOBALS['__l10n']['Comments can be formatted using a simple wiki syntax.'] = '';
$GLOBALS['__l10n']['Comments feed'] = 'Feed dei commenti';
$GLOBALS['__l10n']['Continue reading'] = 'Continua lettura';
$GLOBALS['__l10n']['Document not found'] = 'Documento non trovato';
$GLOBALS['__l10n']['Email address'] = 'Indirizzo email';
$GLOBALS['__l10n']['Email address is not valid'] = 'Indirizzo email non valido';
$GLOBALS['__l10n']['Entries feed'] = 'Feed degli articoli';
$GLOBALS['__l10n']['Explore archives'] = '';
$GLOBALS['__l10n']['Extra menu'] = 'Al menu';
$GLOBALS['__l10n']['From'] = '';
$GLOBALS['__l10n']['FromDay'] = '';
$GLOBALS['__l10n']['Go to homepage'] = '';
$GLOBALS['__l10n']['HTML code is displayed as text and web addresses are automatically converted.'] = 'Il codice HTML è mostrato come testo e gli indirizzi web sono automaticamente convertiti.';
$GLOBALS['__l10n']['Home'] = 'Home';
$GLOBALS['__l10n']['In'] = '';
$GLOBALS['__l10n']['Languages'] = 'Lingue';
$GLOBALS['__l10n']['Links'] = 'Link';
$GLOBALS['__l10n']['Name or nickname'] = 'Nome o nickname';
$GLOBALS['__l10n']['Next entry:'] = 'articoli successivi';
$GLOBALS['__l10n']['On'] = 'Il';
$GLOBALS['__l10n']['Page top'] = '';
$GLOBALS['__l10n']['Password needed'] = 'Password richiesta';
$GLOBALS['__l10n']['Password:'] = 'Password:';
$GLOBALS['__l10n']['Permalink'] = 'Permalink';
$GLOBALS['__l10n']['Powered by %s'] = 'Creato con %s';
$GLOBALS['__l10n']['Preview'] = 'anteprima';
$GLOBALS['__l10n']['Previous entry:'] = 'articoli precedenti';
$GLOBALS['__l10n']['RSS feed is a free blog summary. It provides content (either posts or comments) or summaries of content, together with links to the full versions, and other metadata. The last published items may then be read by your favorite RSS <a href="http://en.wikipedia.org/wiki/Aggregator">aggregator</a>.'] = 'Un feed RSS è il riassunto di un blog. Permette di leggere direttamente i contenuti (come gli articoli o i commenti) o loro riassunti, ed include inoltre un link alla relativa pagina del blog. Per mantenersi aggiornati sui nuovi articoli pubblicati, è possibile iscriversi attraverso un <a href="http://it.wikipedia.org/wiki/Aggregatore">aggregatore di feed</a>.';
$GLOBALS['__l10n']['Read'] = 'Leggi';
$GLOBALS['__l10n']['Remember me on this blog'] = 'Ricordami su questo blog';
$GLOBALS['__l10n']['Required field'] = '';
$GLOBALS['__l10n']['Search'] = 'Cerca';
$GLOBALS['__l10n']['Send'] = '';
$GLOBALS['__l10n']['Simply copy the following URL into your aggregator:'] = 'È sufficiente copiare il seguente URL all\'interno del proprio aggregatore:';
$GLOBALS['__l10n']['Subcategories'] = 'Sotto-categorie';
$GLOBALS['__l10n']['Subscribe'] = 'Sottoscrivi';
$GLOBALS['__l10n']['Subscribe to'] = 'Iscriviti a';
$GLOBALS['__l10n']['Suggestions:'] = '';
$GLOBALS['__l10n']['The document you are looking for does not exist.'] = 'Il documento richiesto non esiste.';
$GLOBALS['__l10n']['The list of recents posts is available'] = '';
$GLOBALS['__l10n']['They posted on the same topic'] = 'Hanno scritto sullo stesso argomento';
$GLOBALS['__l10n']['This blog\'s comments Atom feed'] = 'Feed Atom dei commenti di questo blog';
$GLOBALS['__l10n']['This category\'s comments Atom feed'] = 'Feed Atom dei commenti di questa categoria';
$GLOBALS['__l10n']['This category\'s entries Atom feed'] = 'Feed Atom degli articoli di questa categoria';
$GLOBALS['__l10n']['This post\'s comments Atom feed'] = 'Feed Atom dei commenti di questo articolo';
$GLOBALS['__l10n']['This post\'s comments feed'] = 'Feed dei commenti di questo articolo';
$GLOBALS['__l10n']['To content'] = 'Al contenuto';
$GLOBALS['__l10n']['To menu'] = 'Al menu';
$GLOBALS['__l10n']['To search'] = 'Alla ricerca';
$GLOBALS['__l10n']['Trackback URL'] = 'URL trackback';
$GLOBALS['__l10n']['URL you\'ve tried has typos, or the page has been deleted or moved.'] = '';
$GLOBALS['__l10n']['Use search form'] = '';
$GLOBALS['__l10n']['Website'] = 'Sito web';
$GLOBALS['__l10n']['What is an RSS feed?'] = 'Che cos\'è un feed RSS?';
$GLOBALS['__l10n']['You must give a password to access this area.'] = 'Per accedere in quest\'area del sito è necessario inserire la password.';
$GLOBALS['__l10n']['You must provide a comment'] = 'È necessario inserire un commento';
$GLOBALS['__l10n']['You must provide a valid email address.'] = 'È necessario fornire un indirizzo email valido.';
$GLOBALS['__l10n']['You must provide an author name'] = 'È necessario inserire il nome dell\'autore';
$GLOBALS['__l10n']['Your comment'] = 'Il tuo commento';
$GLOBALS['__l10n']['Your comment has been published.'] = 'Il tuo commento è stato pubblicato.';
$GLOBALS['__l10n']['Your comment has been submitted and will be reviewed for publication.'] = 'Il tuo commento è stato inviato e sarà controllato prima di essere pubblicato.';
$GLOBALS['__l10n']['Your search for <em>%1$s</em> returned <strong>%2$s</strong> result.'] = 'È stato trovato <strong>%2$s</strong> risultato per la ricerca di <em>%1$s</em>.';
$GLOBALS['__l10n']['Your search for <em>%1$s</em> returned <strong>%2$s</strong> results.'] = 'Sono stati trovati <strong>%2$s</strong> risultati per la ricerca di <em>%1$s</em>.';
$GLOBALS['__l10n']['Your search for <em>%1$s</em> returned no result.'] = 'Non è stato trovato alcun risultato per la ricerca di <em>%1$s</em>.';
$GLOBALS['__l10n']['by'] = 'da';
$GLOBALS['__l10n']['here'] = '';
$GLOBALS['__l10n']['in'] = '';
$GLOBALS['__l10n']['next entries'] = 'articoli successivi';
$GLOBALS['__l10n']['no attachments'] = 'nessun allegato';
$GLOBALS['__l10n']['no comments'] = 'nessuno commento';
$GLOBALS['__l10n']['no reactions'] = '';
$GLOBALS['__l10n']['no trackbacks'] = 'nessun trackback';
$GLOBALS['__l10n']['of'] = 'di';
$GLOBALS['__l10n']['on'] = 'il';
$GLOBALS['__l10n']['one attachment'] = 'un allegato';
$GLOBALS['__l10n']['one comment'] = 'un commento';
$GLOBALS['__l10n']['one reaction'] = 'Continua lettura';
$GLOBALS['__l10n']['one trackback'] = 'un trackback';
$GLOBALS['__l10n']['optional'] = 'facoltativo';
$GLOBALS['__l10n']['page'] = 'pagina';
$GLOBALS['__l10n']['preview'] = 'anteprima';
$GLOBALS['__l10n']['previous entries'] = 'articoli precedenti';
$GLOBALS['__l10n']['reactions'] = '';
$GLOBALS['__l10n']['send'] = 'invia';
$GLOBALS['__l10n']['toDay'] = '';
